boto v2.26.1 — boto v2.31.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.31.0 »

# boto v2.26.1

date: | 2014/03/03

This release fixes an issue with the newly-added `boto.rds2` module when trying to use `boto.connect_rds2`. Parameters were not being passed correctly, which would cause an immediate error.

## Changes

- Fixed `boto.connect_rds2` to use kwargs. (commit 3828ece)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.31.0 »